### CLI with data analysis of the game Cartola FC

#### Instalação

```
pip install cartola-stats-cli
```

#### Documentação

  - ```-t10, --top10```: Lista um TOP 10 com os maiores pontuadores

  - ```-bot, --bestofposition```: Recebe um argumento (a posição) e retorna o jogador que mais pontou naquela determina posição.

  - ```-tp, --tposition```: Lista os jogadores que mais pontuarem de cada posição.
